# Manuka Client

Client for Manuka
https://github.com/NeCTAR-RC/manuka/

## Common openstack CLI Commands

List all users

 openstack account user list

Search for a user

 openstack account user search

Show details for a user

 openstack account user show

Update a user

openstack account user set

Pending users

 openstack account pending-user show
 openstack account pending-user list
 openstack account pending-user delete

External IDs

 openstack account external-id set
 openstack account external-id delete
